@@ -5,6 +5,7 @@
 #' @param rmd character: R Markdown document as string 
 #' @param space character: pattern to split a text at spaces (default: \code{'[[:space:]]'})
 #' @param word character: pattern to split a text at word boundaries (default: \code{'[[:space:]]+'})
+#' @param line character: pattern to split lines (default: \code{'\n'})
 #'
 #' @return a list
 #' @export
@@ -13,13 +14,11 @@
 #' file  <- system.file('rmarkdown/rstudio_pdf.Rmd', package="rmdwc")
 #' fcont <- readChar(file, file.info(file)$size)
 #' rmdwcl(fcont)
-rmdwcl <- function (rmd, space='[[:space:]]', word='[[:space:]]+') {
-  fcont <- gsub('```\\{.*?```', '', rmd) 
-  list(words          = strsplit(rmd, word)[[1]],
+rmdwcl <- function (rmd, space='[[:space:]]', word='[[:space:]]+', line="\n") {
+  list(lines          = strsplit(rmd, line)[[1]],
+       words          = strsplit(rmd, word)[[1]],
+       bytes          = charToRaw(rmd),
        chars          = strsplit(rmd, '')[[1]],
-       nonws          = strsplit(gsub(space, '', rmd), '')[[1]],
-       words_chunk    = strsplit(fcont, word)[[1]],
-       chars_chunk    = strsplit(fcont, '')[[1]],
-       nonws_chunk    = strsplit(gsub(space, '', fcont), '')[[1]]
+       nonws          = strsplit(gsub(space, '', rmd), '')[[1]]
   )
 }
\ No newline at end of file
